@@ -25,9 +25,8 @@ commands = {
     },
     DiscordContext.DM_CHANNEL: {
         'register': Command(register,
-                            "Register your Minecraft player. Type password ONLY if you have a non-official account. DO "
-                            "NOT USE YOUR NORMAL PASSWORDS - THEY ARE TRANSMITTED IN PLAIN TEXT THROUGH DISCORD AND "
-                            "THROUGH THE INTERNET WHEN LOGGING IN THE MINECRAFT SERVER!"),
+                            "Register your Minecraft player. For premium accounts you need the password only once. DO "
+                            "NOT USE ANY PASSWORD YOU HAVE SOMEWHERE ELSE!"),
         'unregister': Command(unregister,
                               "Unregister your Minecraft player. Type the player name as a confirmation."),
         'help': Command(help_text, help_text="Show this help."),
@@ -73,5 +72,5 @@ for context in commands.keys():
             usage_text[context].append((cmd_full, cmd.help_text))
     text = ''
     for i in usage_text[context]:
-        text += '  ' + i[0].ljust(max_length, '.') + i[1] + '\n'
+        text += '  ' + i[0].ljust(max_length + 4, '.') + i[1] + '\n'
     usage_text[context] = text
