@@ -15,10 +15,9 @@ from mcdbot.mcdbot import Mcdbot
 
 async def unregister(main: Mcdbot, msg, context, player: str):
     if check_user(main, msg.author):
-        if main.redis.user_get_mc_player(msg.author) == player:
-            await main.redis.atomic_purge_mc_player(player, msg.author)
+        if main.redis.get_player_by_user(msg.author) == player:
             await main.rcon.authme_unregister(player)
-            await main.whitelist.rm_player(player)
+            await main.redis.del_player(player, msg.author)
         else:
             raise McPlayerNotFoundError
     else:
