@@ -40,9 +40,9 @@ def check_user(main: Mcdbot, user: Union[Member, User]):
 
 async def check_mc_player_available(main: Mcdbot, user: Union[Member, User], player: str):
     check_mc_player_name_correctness(player)
-    if await main.redis.mc_player_exists(player):
+    if await main.redis.player_exists(player):
         raise McPlayerNameExistsError
-    if await main.redis.user_has_mc_player(user):
+    if await main.redis.has_user_player(user):
         raise McPlayerAlreadyRegisteredError
 
 
